#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp
version:              2.2.0.0
visibility:           public
id:                   lsp-2.2.0.0-5VWxu1we8UwCjDB58kn7YJ
key:                  lsp-2.2.0.0-5VWxu1we8UwCjDB58kn7YJ
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:             Haskell library for the Microsoft Language Server Protocol
description:
    An implementation of the types, and basic message server to
    allow language implementors to support the Language Server
    Protocol for their specific language.

    An example of this is for Haskell via the Haskell Language
    Server, at https://github.com/haskell/haskell-language-server

category:             Development
abi:                  c4ac5e97be730a34344f9e38377ebc3c
exposed:              True
exposed-modules:
    Language.LSP.Diagnostics, Language.LSP.Logging,
    Language.LSP.Protocol.Capabilities from lsp-types-2.0.2.0-5duUulTzHKp9nJAuNg11F9:Language.LSP.Protocol.Capabilities,
    Language.LSP.Protocol.Lens from lsp-types-2.0.2.0-5duUulTzHKp9nJAuNg11F9:Language.LSP.Protocol.Lens,
    Language.LSP.Protocol.Message from lsp-types-2.0.2.0-5duUulTzHKp9nJAuNg11F9:Language.LSP.Protocol.Message,
    Language.LSP.Protocol.Types from lsp-types-2.0.2.0-5duUulTzHKp9nJAuNg11F9:Language.LSP.Protocol.Types,
    Language.LSP.Server, Language.LSP.VFS

hidden-modules:
    Language.LSP.Server.Control Language.LSP.Server.Core
    Language.LSP.Server.Processing

import-dirs:          /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp
hs-libraries:         HSlsp-2.2.0.0-5VWxu1we8UwCjDB58kn7YJ
depends:
    aeson-2.2.2.0-6vy5nFkYOklEBUzF5CRv7u
    async-2.2.6-FyNZXdji95t98VleCj3HXu
    attoparsec-0.14.4-5xxMJ7hMTSZEwvbcpfcCWS base-4.18.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.7-5dsyDH0ASi73NTTs3BPNtX
    containers-0.6.7 data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1
    hashable-1.4.7.0-Eia1GH7GKUH7V9HVPMehAJ
    lens-5.3.5-FTj0s0XQNe34VtbjGE3NFc
    lens-aeson-1.2.3-9IgOKwJVpOZ2edQX03cozD
    lsp-types-2.0.2.0-5duUulTzHKp9nJAuNg11F9 mtl-2.3.1
    prettyprinter-1.7.2-IAT1Mz24wwt4xYlQDqw7Fl
    random-1.2.1.3-GfiOoTkiJ8dHrTrBUL8yXz
    row-types-1.0.1.2-G78nNUgj8tKI03rHtAZWCt
    sorted-list-0.2.3.1-1ugxMEeMWlN3baiD3AaOhr stm-2.5.1.0
    temporary-1.3-EJjX5K17BD86XZ5zCqX06b text-2.0.2
    text-rope-0.3-LWzSWMdJmcpJ6I9z3sZgKt transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.21-CG6y7kseADB9y4YJD0dypo
    uuid-1.3.16.1-DPU1pyFvmFvGXgW1eSh0Oa

haddock-interfaces:   /usr/share/doc/haskell-lsp/html/lsp.haddock
haddock-html:         /usr/share/doc/haskell-lsp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

